==> mediawiki_1.11.2.orig.tar.gz: mediawiki-1.11.2/languages/messages/MessagesRoa_rup.php <==
<?php
/** Aromanian (Armãneashce)
 *
 * Translators: Hakka (with the help of a native speaker Dumitrachi T. Fundu)
 *
 * @addtogroup Language
 * @author Niklas Laxström
 */


$messages = array(
# Dates
'sunday'        => 'Dumãnicã',
'monday'        => 'Lune',
'tuesday'       => 'Martsã',
'wednesday'     => 'Njercure',
'thursday'      => 'Gioia',
'friday'        => 'Vinirã',
'saturday'      => 'Sãmbãtã',
'january'       => 'Yinar',
'february'      => 'Shcurtu',
'march'         => 'Martsu',
'april'         => 'Aprir',
'may_long'      => 'Mailu',
'june'          => 'Cirishar',
'july'          => 'Alunar',
'august'        => 'Avgustu',
'september'     => 'Yizmaciunjle',
'october'       => 'Xumedru',
'november'      => 'Brumar',
'december'      => 'Andreulu',
'january-gen'   => 'Yinar',
'february-gen'  => 'Shcurtu',
'march-gen'     => 'Martsu',
'april-gen'     => 'Aprir',
'may-gen'       => 'Mailu',
'june-gen'      => 'Cirishar',
'july-gen'      => 'Alunar',
'august-gen'    => 'Avgustu',
'september-gen' => 'Yizmaciunjle',
'october-gen'   => 'Xumedru',
'november-gen'  => 'Brumar',
'december-gen'  => 'Andreulu',

'article'        => 'Articlu',
'cancel'         => 'Alasã',
'qbedit'         => 'Alãxiri',
'qbspecialpages' => 'Frãndzã spetsiale',
'mytalk'         => 'Zburare-a mea',
'navigation'     => 'Navigatsia',

'help'             => 'Agiutor',
'search'           => 'Caftã',
'searchbutton'     => 'Caftã',
'go'               => 'Du-vã',
'searcharticle'    => 'Du-vã',
'history_short'    => 'Istoria',
'printableversion' => 'Verzia ti tipuseare',
'permalink'        => 'Ligãtura permanentã',
'edit'             => 'Alãxiri',
'delete'           => 'Ashcirdzire',
'protect'          => 'Apurã',
'talk'             => 'Discusiur',
'toolbox'          => 'Cutia di hãlate',
'otherlanguages'   => 'Pi alte limbe',
'jumptonavigation' => 'Navigatsia',
'jumptosearch'     => 'Caftã',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents' => 'Evenimente di tora',
'disclaimers'   => 'Nipricunuschire',
'edithelp'      => 'Agiutor ti alãxire',
'mainpage'      => 'Prota frãndzã',
'portal'        => 'Portal-a comunitatiljei',
'sitesupport'   => 'Donatsiur',

'newmessageslink' => 'dimãndare nao',
'editsection'     => 'Alãxiri',
'editold'         => 'Alãxiri',

# Short words for each namespace, by default used in the 'article' tab in monobook
'nstab-main'     => 'Articlu',
'nstab-user'     => 'Frãndza-a ufilizitirolui',
'nstab-template' => 'Shablon',

# General errors
'viewsource' => 'Videts-u fãntãnã',

# Login and logout pages
'welcomecreation'    => '== Ghine vinish, $1 == 

Isape a vostrã ira adratã. Nu agãrshits s-le alãxits alidzerle-a vostre ti {{SITENAME}}.',
'yourname'           => 'Numa di ufilizitor:',
'yourpassword'       => 'Cljao:',
'yourpasswordagain'  => 'Bãgats-u cljao iara:',
'remembermypassword' => 'Apurã-u ligãtura-a mea pi compiuterlu aistu',
'login'              => 'Ligats-vã',
'userlogin'          => 'Ligats-vã / Fãtsets Isape',
'logout'             => 'Disligats-vã',
'userlogout'         => 'Disligats-vã',
'notloggedin'        => 'Nu hits ligats',
'createaccount'      => 'Fãtsets Isape',
'gotaccountlink'     => 'Ligats-vã',
'youremail'          => 'E-mail:',
'username'           => 'Numa di ufilizitor:',

# Edit pages
'summary'            => 'Rezime',
'minoredit'          => 'Aistã easte alãxire njicã',
'watchthis'          => 'Mutrits-u frãndzã aistã',
'savearticle'        => 'Avigljats-u frãndzã',
'showpreview'        => 'Spuni u-privideare',
'showdiff'           => 'Spuni le-alãxirle',
'whitelistedittitle' => 'Lipseashce s-vã ligats ta s-alãxits',
'loginreqlink'       => 'Ligats-vã',

# Search results
'powersearch' => 'Caftã',

# Preferences page
'preferences'       => 'Alidzerle-a meale',
'mypreferences'     => 'Alidzerle-a meale',
'prefsnologin'      => 'Nu hits ligats',
'searchresultshead' => 'Caftã',

# Recent changes
'recentchanges' => 'Alãxiri',

# Recent changes linked
'recentchangeslinked' => 'Alãxiri ligate',

# Upload
'upload'          => 'Pitritsets file',
'uploadbtn'       => 'Pitritsets file',
'uploadnologin'   => 'Nu hits ligats',
'filedesc'        => 'Rezime',
'watchthisupload' => 'Mutrits-u frãndzã aistã',

# Image list
'ilsubmit' => 'Caftã',

'brokenredirects-edit'   => '(Alãxiri)',
'brokenredirects-delete' => '(Ashcirdzire)',

# Miscellaneous special pages
'randompage'        => 'Frãndzã di nipandicã',
'specialpages'      => 'Frãndzã spetsiale',
'newpages-username' => 'Numa di ufilizitor:',
'move'              => 'Tradzets',
'movethispage'      => 'Tradzets-u frãndza aistã',

# Book sources
'booksources-go' => 'Du-vã',

# Special:Log
'log-search-submit' => 'Du-vã',

# Special:Allpages
'allpagessubmit' => 'Du-vã',

# Watchlist
'watchlist'     => 'Lista-a mea di videare',
'mywatchlist'   => 'Lista-a mea di videare',
'watchnologin'  => 'Nu hits ligats',
'watch'         => 'Videts',
'watchthispage' => 'Mutrits-u frãndzã aistã',
'unwatch'       => 'Azãptãsits videare',

# Restrictions (nouns)
'restriction-edit' => 'Alãxiri',
'restriction-move' => 'Tradzets',

# Undelete
'undelete-search-submit' => 'Caftã',

# Contributions
'contributions' => 'Ufilizitor:Contributsiur',
'mycontris'     => 'Contributsiile-a meale',

'sp-contributions-submit' => 'Caftã',

# What links here
'whatlinkshere' => 'Tsi s-leadze cu aistu',

# Block/unblock
'ipbreason'          => 'Itia:',
'ipblocklist-submit' => 'Caftã',

# Move page
'movepage'    => 'Tradzets-u frãndzã',
'movearticle' => 'Tradzets-u frãndzã:',
'move-watch'  => 'Mutrits-u frãndzã aistã',
'movepagebtn' => 'Tradzets-u frãndzã',
'movedto'     => 'tradzitã tu',
'1movedto2'   => '[[$1]] s-trãdzi tu [[$2]]',
'movereason'  => 'Itia:',

# Namespace 8 related
'allmessages' => 'Dimãndãri systemitse',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Alidzerle-a meale',
'tooltip-pt-logout'      => 'Disligats-vã',
'tooltip-p-logo'         => 'Prota frãndzã',

'youhavenewmessagesmulti' => 'Avets nãi dimãndãri pi $1',

# Multipage image navigation
'imgmultigo' => 'Du-vã!',

# Table pager
'table_pager_limit_submit' => 'Du-vã',

);

==> mediawiki_1.12.0.orig.tar.gz: mediawiki-1.12.0/languages/messages/MessagesRoa_rup.php <==
<?php
/** Aromanian (Armãneashce)
 *
 * @addtogroup Language
 *
 * @author Niklas Laxström
 * @author Hakka (with the help of a native speaker Dumitrachi T. Fundu)
 * @author Hakka
 */

$messages = array(
# Dates
'sunday'        => 'Dumãnicã',
'monday'        => 'Lune',
'tuesday'       => 'Martsã',
'wednesday'     => 'Njercure',
'thursday'      => 'Gioia',
'friday'        => 'Vinirã',
'saturday'      => 'Sãmbãtã',
'january'       => 'Yinar',
'february'      => 'Shcurtu',
'march'         => 'Martsu',
'april'         => 'Aprir',
'may_long'      => 'Mailu',
'june'          => 'Cirishar',
'july'          => 'Alunar',
'august'        => 'Avgustu',
'september'     => 'Yizmaciunjle',
'october'       => 'Xumedru',
'november'      => 'Brumar',
'december'      => 'Andreulu',
'january-gen'   => 'Yinar',
'february-gen'  => 'Shcurtu',
'march-gen'     => 'Martsu',
'april-gen'     => 'Aprir',
'may-gen'       => 'Mailu',
'june-gen'      => 'Cirishar',
'july-gen'      => 'Alunar',
'august-gen'    => 'Avgustu',
'september-gen' => 'Yizmaciunjle',
'october-gen'   => 'Xumedru',
'november-gen'  => 'Brumar',
'december-gen'  => 'Andreulu',

'article'        => 'Articlu',
'cancel'         => 'Alasã',
'qbedit'         => 'Alãxiri',
'qbspecialpages' => 'Frãndzã spetsiale',
'mytalk'         => 'Zburare-a mea',
'navigation'     => 'Navigatsia',

'help'             => 'Agiutor',
'search'           => 'Caftã',
'searchbutton'     => 'Caftã',
'go'               => 'Du-vã',
'searcharticle'    => 'Du-vã',
'history_short'    => 'Istoria',
'printableversion' => 'Verzia ti tipuseare',
'permalink'        => 'Ligãtura permanentã',
'edit'             => 'Alãxiri',
'delete'           => 'Ashcirdzire',
'protect'          => 'Apurã',
'talk'             => 'Discusiur',
'toolbox'          => 'Cutia di hãlate',
'otherlanguages'   => 'Pi alte limbe',
'jumptonavigation' => 'Navigatsia',
'jumptosearch'     => 'Caftã',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents' => 'Evenimente di tora',
'disclaimers'   => 'Nipricunuschire',
'edithelp'      => 'Agiutor ti alãxire',
'mainpage'      => 'Prota frãndzã',
'portal'        => 'Portal-a comunitatiljei',
'sitesupport'   => 'Donatsiur',

'newmessageslink'         => 'dimãndare nao',
'youhavenewmessagesmulti' => 'Avets nãi dimãndãri pi $1',
'editsection'             => 'Alãxiri',
'editold'                 => 'Alãxiri',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Articlu',
'nstab-user'     => 'Frãndza-a ufilizitirolui',
'nstab-template' => 'Shablon',

# General errors
'viewsource' => 'Videts-u fãntãnã',

# Login and logout pages
'welcomecreation'    => '== Ghine vinish, $1 == 

Isape a vostrã ira adratã. Nu agãrshits s-le alãxits alidzerle-a vostre ti {{SITENAME}}.',
'yourname'           => 'Numa di ufilizitor:',
'yourpassword'       => 'Cljao:',
'yourpasswordagain'  => 'Bãgats-u cljao iara:',
'remembermypassword' => 'Apurã-u ligãtura-a mea pi compiuterlu aistu',
'login'              => 'Ligats-vã',
'userlogin'          => 'Ligats-vã / Fãtsets Isape',
'logout'             => 'Disligats-vã',
'userlogout'         => 'Disligats-vã',
'notloggedin'        => 'Nu hits ligats',
'createaccount'      => 'Fãtsets Isape',
'gotaccountlink'     => 'Ligats-vã',
'youremail'          => 'E-mail:',
'username'           => 'Numa di ufilizitor:',

# Edit pages
'summary'            => 'Rezime',
'minoredit'          => 'Aistã easte alãxire njicã',
'watchthis'          => 'Mutrits-u frãndzã aistã',
'savearticle'        => 'Avigljats-u frãndzã',
'showpreview'        => 'Spuni u-privideare',
'showdiff'           => 'Spuni le-alãxirle',
'whitelistedittitle' => 'Lipseashce s-vã ligats ta s-alãxits',
'loginreqlink'       => 'Ligats-vã',

# Search results
'powersearch' => 'Caftã',

# Preferences page
'preferences'       => 'Alidzerle-a meale',
'mypreferences'     => 'Alidzerle-a meale',
'prefsnologin'      => 'Nu hits ligats',
'searchresultshead' => 'Caftã',

# Recent changes
'recentchanges' => 'Alãxiri',

# Recent changes linked
'recentchangeslinked' => 'Alãxiri ligate',

# Upload
'upload'          => 'Pitritsets file',
'uploadbtn'       => 'Pitritsets file',
'uploadnologin'   => 'Nu hits ligats',
'filedesc'        => 'Rezime',
'watchthisupload' => 'Mutrits-u frãndzã aistã',

# Image list
'ilsubmit' => 'Caftã',

# Random page
'randompage' => 'Frãndzã di nipandicã',

'brokenredirects-edit'   => '(Alãxiri)',
'brokenredirects-delete' => '(Ashcirdzire)',

# Miscellaneous special pages
'specialpages'      => 'Frãndzã spetsiale',
'newpages-username' => 'Numa di ufilizitor:',
'move'              => 'Tradzets',
'movethispage'      => 'Tradzets-u frãndza aistã',

# Book sources
'booksources-go' => 'Du-vã',

# Special:Log
'log-search-submit' => 'Du-vã',

# Special:Allpages
'allpagessubmit' => 'Du-vã',

# Watchlist
'watchlist'     => 'Lista-a mea di videare',
'mywatchlist'   => 'Lista-a mea di videare',
'watchnologin'  => 'Nu hits ligats',
'watch'         => 'Videts',
'watchthispage' => 'Mutrits-u frãndzã aistã',
'unwatch'       => 'Azãptãsits videare',

# Restrictions (nouns)
'restriction-edit' => 'Alãxiri',
'restriction-move' => 'Tradzets',

# Undelete
'undelete-search-submit' => 'Caftã',

# Contributions
'contributions' => 'Ufilizitor:Contributsiur',
'mycontris'     => 'Contributsiile-a meale',

'sp-contributions-submit' => 'Caftã',

# What links here
'whatlinkshere' => 'Tsi s-leadze cu aistu',

# Block/unblock
'ipbreason'          => 'Itia:',
'ipblocklist-submit' => 'Caftã',

# Move page
'movepage'    => 'Tradzets-u frãndzã',
'movearticle' => 'Tradzets-u frãndzã:',
'move-watch'  => 'Mutrits-u frãndzã aistã',
'movepagebtn' => 'Tradzets-u frãndzã',
'movedto'     => 'tradzitã tu',
'1movedto2'   => '[[$1]] s-trãdzi tu [[$2]]',
'movereason'  => 'Itia:',

# Namespace 8 related
'allmessages' => 'Dimãndãri systemitse',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Alidzerle-a meale',
'tooltip-pt-logout'      => 'Disligats-vã',
'tooltip-p-logo'         => 'Prota frãndzã',

# Multipage image navigation
'imgmultigo' => 'Du-vã!',

# Table pager
'table_pager_limit_submit' => 'Du-vã',

);
